@@ -7,16 +7,17 @@ from aiortc import MediaStreamTrack, RTCPeerConnection
 from aiortc.rtcrtpreceiver import RemoteStreamTrack
 
 
-
 class GSPeerConnectionWatcher:
     class VideoTransformTrack(MediaStreamTrack):
         kind = "video"
+
         def __init__(self, track: RemoteStreamTrack, gsdbs, source, onframe):
             super().__init__()
             self.track = track
             self.onframe = onframe
             self.source = source
             self.gsdbs = gsdbs
+
         async def recv(self):
             frame = await self.track.recv()
             # frame = await self.track._queue.get()
@@ -65,7 +66,7 @@ class GSPeerConnectionWatcher:
             def on_track(track):
                 if track.kind == "video":
                     if self.ontrack is not None:
-                        self.ontrack(track)
+                        self.ontrack(self.gsdbs, track)
 
                 @track.on("ended")
                 async def on_ended():
